@@ -5,21 +5,22 @@ import os
 import nox
 
 ROOT = Path(__file__).parent
-TESTS = ROOT / "tests"
 PYPROJECT = ROOT / "pyproject.toml"
 DOCS = ROOT / "docs"
+TESTS = ROOT / "tests"
 
 REQUIREMENTS = dict(
     docs=DOCS / "requirements.txt",
     tests=TESTS / "requirements.txt",
 )
 REQUIREMENTS_IN = [  # this is actually ordered, as files depend on each other
-    path.parent / f"{path.stem}.in" for path in REQUIREMENTS.values()
+    (path.parent / f"{path.stem}.in", path) for path in REQUIREMENTS.values()
 ]
 
-SUPPORTED = ["3.8", "3.9", "3.10", "3.11", "3.12", "3.13", "pypy3.10"]
+SUPPORTED = ["3.8", "3.9", "3.10", "pypy3.10", "3.11", "3.12", "3.13"]
 LATEST = "3.12"
 
+nox.options.default_venv_backend = "uv|virtualenv"
 nox.options.sessions = []
 
 
@@ -37,7 +38,18 @@ def tests(session):
     """
     Run the test suite with a corresponding Python version.
     """
-    session.install("-r", REQUIREMENTS["tests"])
+    # Really we want --profile=test here (for
+    # https://github.com/crate-py/rpds/pull/87#issuecomment-2291409297)
+    # but it produces strange symbol errors saying:
+    #   dynamic module does not define module export function (PyInit_rpds)
+    # so OK, dev it is.
+    session.install(
+        "--config-settings",
+        "build-args=--profile=dev",
+        "--no-cache",
+        "-r",
+        REQUIREMENTS["tests"],
+    )
 
     if session.posargs and session.posargs[0] == "coverage":
         if len(session.posargs) > 1 and session.posargs[1] == "github":
@@ -89,7 +101,16 @@ def style(session):
     Check Python code style.
     """
     session.install("ruff")
-    session.run("ruff", "check", ROOT)
+    session.run("ruff", "check", TESTS, __file__)
+
+
+@session()
+def typing(session):
+    """
+    Check the codebase using pyright by type checking the test suite.
+    """
+    session.install("pyright", ROOT, "-r", REQUIREMENTS["tests"])
+    session.run("pyright", TESTS)
 
 
 @session(tags=["docs"])
@@ -145,15 +166,17 @@ def docs_style(session):
 @session(default=False)
 def requirements(session):
     """
-    Update the project's pinned requirements. Commit the result.
+    Update the project's pinned requirements.
+
+    You should commit the result afterwards.
     """
-    session.install("pip-tools")
-    for each in REQUIREMENTS_IN:
-        session.run(
-            "pip-compile",
-            "--resolver",
-            "backtracking",
-            "--strip-extras",
-            "-U",
-            each.relative_to(ROOT),
-        )
+    if session.venv_backend == "uv":
+        cmd = ["uv", "pip", "compile"]
+    else:
+        session.install("pip-tools")
+        cmd = ["pip-compile", "--resolver", "backtracking", "--strip-extras"]
+
+    for each, out in REQUIREMENTS_IN:
+        # otherwise output files end up with silly absolute path comments...
+        relative = each.relative_to(ROOT)
+        session.run(*cmd, "--upgrade", "--output-file", out, relative)
